@@ -1,6 +1,6 @@
 /* GNU ed - The GNU line editor.
    Copyright (C) 1993, 1994 Andrew L. Moore, Talke Studio
-   Copyright (C) 2006-2024 Antonio Diaz Diaz.
+   Copyright (C) 2006-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -84,10 +84,10 @@ bool set_prompt( const char * const s )
 void set_verbose( void ) { verbose = true; }
 
 
-static const line_t * mark[26];			/* line markers */
+static const line_node * mark[26];		/* line markers */
 static int markno;				/* line marker count */
 
-static bool mark_line_node( const line_t * const lp, int c )
+static bool mark_line_node( const line_node * const lp, int c )
   {
   c -= 'a';
   if( c < 0 || c >= 26 ) { set_error_msg( inv_mark_ch ); return false; }
@@ -97,7 +97,7 @@ static bool mark_line_node( const line_t * const lp, int c )
   }
 
 
-void unmark_line_node( const line_t * const lp )
+void unmark_line_node( const line_node * const lp )
   {
   int i;
   for( i = 0; markno && i < 26; ++i )
@@ -466,7 +466,8 @@ static bool command_s( const char ** const ibufpp, int * const pflagsp,
     if( !extract_replacement( ibufpp, isglobal ) ) return false;
     pflags = 0; snum = 1;
     bool ignore_case = false;
-    if( **ibufpp == '\n' ) pflags = pf_p;	/* omitted last delimiter */
+    if( **ibufpp == '\n' )			/* omitted last delimiter */
+      { ++*ibufpp; pflags = pf_p; }		/* skip newline for global */
     else
       { if( **ibufpp == delimiter ) ++*ibufpp;		/* skip delimiter */
         if( !get_command_s_suffix( ibufpp, &pflags, &snum, &ignore_case ) )
@@ -711,7 +712,7 @@ static int exec_global( const char ** const ibufpp, const int pflags,
   clear_undo_stack();
   while( true )
     {
-    const line_t * const lp = next_active_node();
+    const line_node * const lp = next_active_node();
     if( !lp ) break;
     set_current_addr( get_line_node_addr( lp ) );
     if( current_addr() < 0 ) return ERR;
